@@ -2,7 +2,7 @@
 #'
 #' Function constructs centered moving average based on state space SMA
 #'
-#' If the otder is odd, then the function constructs SMA(order) and
+#' If the order is odd, then the function constructs SMA(order) and
 #' shifts it back in time. Otherwise an AR(order+1) model is constructed
 #' with the preset parameters:
 #'
@@ -90,7 +90,7 @@ cma <- function(data, order=NULL, silent=TRUE){
     }
 
     ##### data #####
-    if(any(class(data)=="smooth.sim")){
+    if(any(is.smooth.sim(data))){
         data <- data$data;
     }
     else if(class(data)=="Mdata"){
