@@ -11,9 +11,8 @@ utils::globalVariables(c("mvrnorm"));
 #'
 #' @param model Type of ETS model. This can consist of 3 or 4 chars:
 #' \code{ANN}, \code{AAN}, \code{AAdN}, \code{AAA}, \code{AAdA} etc.
-#' Only pure additive and pure multiplicative models are supported. In the
-#' latter case the data is generated using additive model and then
-#' exponentiated.
+#' Only pure additive models are supported. If you want to have multiplicative
+#' one, then just take exponent of the generated data.
 #' @param obs Number of observations in each generated time series.
 #' @param nsim Number of series to generate (number of simulations to do).
 #' @param nSeries Number of series in each generated group of series.
@@ -79,14 +78,24 @@ utils::globalVariables(c("mvrnorm"));
 #'
 #' # Create 40 observations of quarterly data using AAA model with errors
 #' # from normal distribution
-#' \dontrun{VES.AAA <- sim.ves(model="AAA",frequency=4,obs=40,nSeries=3,
+#' \dontrun{VESAAA <- sim.ves(model="AAA",frequency=4,obs=40,nSeries=3,
 #'                    randomizer="rnorm",mean=0,sd=100)}
 #'
 #' # You can also use mvrnorm function from MASS package as randomizer,
 #' # but you need to provide mu and Sigma explicitly
-#' \dontrun{VES.ANN <- sim.ves(model="ANN",frequency=4,obs=40,nSeries=2,
+#' \dontrun{VESANN <- sim.ves(model="ANN",frequency=4,obs=40,nSeries=2,
 #'                    randomizer="mvrnorm",mu=c(100,50),Sigma=matrix(c(40,20,20,30),2,2))}
 #'
+#' # When generating the data with multiplicative model a more diligent definitiion
+#' # of parameters is needed. Here's an example with MMM model:
+#'
+#' VESMMM <- sim.ves("AAA", obs=120, nSeries=2, frequency=12, initial=c(10,0),
+#'           initialSeason=runif(12,-1,1), persistence=c(0.06,0.05,0.2), mean=0, sd=0.03)
+#' VESMMM$data <- exp(VESMMM$data)
+#'
+#' # Note that smoothing parameters should be low and the standard diviation should
+#' # definitely be less than 0.1. Otherwise you might face the explosions.
+#'
 #' @export sim.ves
 sim.ves <- function(model="ANN", obs=10, nsim=1, nSeries=2,
                    frequency=1, persistence=NULL, phi=1,
@@ -452,7 +461,7 @@ sim.ves <- function(model="ANN", obs=10, nsim=1, nSeries=2,
     }
     else{
         for(i in 1:nSeries){
-            arrayStates[((i-1)*nComponentsNonSeasonal)+(1:nComponentsNonSeasonal),1:modelLagsMax,] <-
+            arrayStates[((i-1)*nComponentsAll)+(1:nComponentsNonSeasonal),1:modelLagsMax,] <-
                 initial[(i-1)*nComponentsNonSeasonal+(1:nComponentsNonSeasonal),1];
         }
     }
@@ -491,7 +500,9 @@ sim.ves <- function(model="ANN", obs=10, nsim=1, nSeries=2,
             arrayErrors[,,] <- rs(nsim*obs*nSeries);
         }
         # Make variance sort of meaningful
-        arrayErrors <- arrayErrors * sqrt(abs(arrayStates[1,1,1]));
+        if(arrayStates[1,1,1]!=0){
+            arrayErrors <- arrayErrors * sqrt(abs(arrayStates[1,1,1]));
+        }
     }
 
 # If arguments are passed, use them. WE ASSUME HERE THAT USER KNOWS WHAT HE'S DOING!
