@@ -7,10 +7,10 @@ require(smooth)
 require(Mcomp)
 
 ## ----ces_N2457-----------------------------------------------------------
-ces(M3$N2457$x, h=18, holdout=TRUE)
+ces(M3$N2457$x, h=18, holdout=TRUE, silent=FALSE)
 
 ## ----auto_ces_N2457------------------------------------------------------
-auto.ces(M3$N2457$x, h=18, holdout=TRUE, intervals="p")
+auto.ces(M3$N2457$x, h=18, holdout=TRUE, intervals="p", silent=FALSE)
 
 ## ----auto_ces_N2457_optimal----------------------------------------------
 auto.ces(M3$N2457$x, h=18, holdout=TRUE, initial="o", intervals="sp")
