@@ -115,12 +115,12 @@ plot(x)
 plot(ourData)
 par(mfcol=c(1,1))
 
-## ----simulate_smooth_ges-------------------------------------------------
+## ----simulate_smooth_gum-------------------------------------------------
 x <- ts(100 + rnorm(120,0,5) + rep(runif(12,-50,50),10)*rep(c(1:10),each=12) ,frequency=12)
-ourModel <- auto.ges(x, h=18, silent=TRUE)
+ourModel <- auto.gum(x, h=18, silent=TRUE)
 ourData <- simulate(ourModel, nsim=50)
 
-## ----simulate_smooth_ges_compare-----------------------------------------
+## ----simulate_smooth_gum_compare-----------------------------------------
 par(mfcol=c(1,2))
 plot(x)
 plot(ourData)
